@@ -1,10 +1,12 @@
 from .client import Metablock
 from .components import MetablockEntity, MetablockError, MetablockResponseError
+from .extensions import Extension, Plugin
 from .orgs import Org
-from .spaces import Extension, Service, Space, SpaceExtension
+from .spaces import Service, Space, SpaceExtension
 from .user import User
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
+
 __all__ = [
     "Metablock",
     "MetablockError",
@@ -13,6 +15,7 @@ __all__ = [
     "Space",
     "Service",
     "Extension",
+    "Plugin",
     "SpaceExtension",
     "Org",
     "User",
