@@ -58,17 +58,6 @@ class SpaceServices(Services):
         return "%s/%s" % (self.root.url, self.name)
 
 
-# Extension
-class Extension(MetablockEntity):
-    """Object representing an Extension"""
-
-
-class Extensions(CrudComponent):
-    """Extensions"""
-
-    Entity = Extension
-
-
 # SpaceExtension
 class SpaceExtension(MetablockEntity):
     """Object representing an SpaceExtension"""
@@ -81,17 +70,6 @@ class SpaceExtensions(CrudComponent):
         return "%s/%s" % (self.root.url, self.name)
 
 
-# Plugin
-class Plugin(MetablockEntity):
-    """Object representing an Plugin"""
-
-
-class Plugins(CrudComponent):
-    """Plugins"""
-
-    Entity = Plugin
-
-
 # ServicePlugin
 
 
